@@ -6,5 +6,10 @@
 #' @docType package
 #' @name MicroMoB
 #'
+#' @importFrom utils getFromNamespace
+#' @importFrom httpuv startServer stopServer
+#'
 #' @useDynLib MicroMoB, .registration = TRUE
 "_PACKAGE"
+
+findPort <- getFromNamespace("findPort", "plumber")
